@@ -1,5 +1,7 @@
 plot.MixedContContIT <- plot.FixedContContIT <- function(x, Trial.Level=TRUE, Weighted=TRUE, Indiv.Level=TRUE, 
-                                                           Xlab.Indiv, Ylab.Indiv, Xlab.Trial, Ylab.Trial, Main.Trial, Main.Indiv, Par=par(oma=c(0, 0, 0, 0), mar=c(5.1, 4.1, 4.1, 2.1)),...){
+                                                           Xlab.Indiv, Ylab.Indiv, Xlab.Trial, Ylab.Trial, Main.Trial, Main.Indiv, 
+                                                         Par=par(oma=c(0, 0, 0, 0), mar=c(5.1, 4.1, 4.1, 2.1)),...){
+  
   Object <- x 
   if (Trial.Level==TRUE){ 
     if (missing(Xlab.Trial)) {Xlab.Trial <- expression(paste("Treatment effect on the Surrogate endpoint ", (alpha[i])))}
